==> 1.0.69+1.tar.gz: lib/components/UikProductCardGrid.dart <==
//import 'package:ui_sdk/components/UikProductCardBig.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikTextProps.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

import '../props/UikProductCardGridProps.dart';

class UikProductCardGrid extends UikWidget {
  WidgetType _widgetType;
  UikProductCardGridProps _uikProductCardGridProps;
  UikProductCardGrid(this._widgetType, this._uikProductCardGridProps)
      : super(_widgetType, _uikProductCardGridProps);

  @override
  _UikProductCardGridState createState() =>
      _UikProductCardGridState(_uikProductCardGridProps);
}

class _UikProductCardGridState extends State<UikProductCardGrid> {
  UikProductCardGridProps _uikProductCardGridProps;
  _UikProductCardGridState(this._uikProductCardGridProps);
  // int index = 0;
  // double ff = _uikProductCardGridProps;
  @override
  Widget build(BuildContext context) {
    return Container(
      height: (_uikProductCardGridProps.productCards.length / 3) *
          _uikProductCardGridProps.height,
      //decoration: BoxDecoration(border: Border.all()),
      margin: EdgeInsets.only(
        top: _uikProductCardGridProps.topMargin,
        left: _uikProductCardGridProps.leftMargin,
        right: _uikProductCardGridProps.rightMargin,
        bottom: _uikProductCardGridProps.bottomMargin,
      ),
      child: GridView.builder(
        physics: _uikProductCardGridProps.isScrollable
            ? const BouncingScrollPhysics()
            : const NeverScrollableScrollPhysics(),
        shrinkWrap: true,
        //width = screen/3
        //height = 85
        itemCount: _uikProductCardGridProps.productCards.length,
        gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: _uikProductCardGridProps.crossAxisCount,
          //  childAspectRatio = width/height
          // childAspectRatio: (MediaQuery.of(context).size.width /
          //         _uikProductCardGridProps.crossAxisCount) /
          //     _uikProductCardGridProps.height,
          childAspectRatio: _uikProductCardGridProps.childAspectRatio,
          crossAxisSpacing: 16.0,
          // mainAxisSpacing: 16.0,
        ),
        itemBuilder: (BuildContext context, int index) {
          return Container(
            //  decoration: BoxDecoration(border: Border.all(color: Colors.pink)),
            child: _uikProductCardGridProps.productCards[index],
          );
        },
      ),
    );
  }
}

==> 1.0.75+1.tar.gz: lib/components/UikProductCardGrid.dart <==
//import 'package:ui_sdk/components/UikProductCardBig.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikTextProps.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

import '../props/UikProductCardGridProps.dart';

class UikProductCardGrid extends UikWidget {
  WidgetType _widgetType;
  UikProductCardGridProps _uikProductCardGridProps;
  UikProductCardGrid(this._widgetType, this._uikProductCardGridProps)
      : super(_widgetType, _uikProductCardGridProps);

  @override
  _UikProductCardGridState createState() =>
      _UikProductCardGridState(_uikProductCardGridProps);
}

class _UikProductCardGridState extends State<UikProductCardGrid> {
  UikProductCardGridProps _uikProductCardGridProps;
  _UikProductCardGridState(this._uikProductCardGridProps);
  // int index = 0;
  // double ff = _uikProductCardGridProps;
  @override
  Widget build(BuildContext context) {
    return Container(
      // height: (_uikProductCardGridProps.productCards.length / 3) *
      //     _uikProductCardGridProps.height,
      //decoration: BoxDecoration(border: Border.all()),
      margin: EdgeInsets.only(
        top: _uikProductCardGridProps.topMargin,
        left: _uikProductCardGridProps.leftMargin,
        right: _uikProductCardGridProps.rightMargin,
        bottom: _uikProductCardGridProps.bottomMargin,
      ),
      child: GridView.builder(
        physics: _uikProductCardGridProps.isScrollable
            ? const BouncingScrollPhysics()
            : const NeverScrollableScrollPhysics(),
        shrinkWrap: true,
        //width = screen/3
        //height = 85
        itemCount: _uikProductCardGridProps.productCards.length,
        gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: _uikProductCardGridProps.crossAxisCount,
          //  childAspectRatio = width/height
          // childAspectRatio: (MediaQuery.of(context).size.width /
          //         _uikProductCardGridProps.crossAxisCount) /
          //     _uikProductCardGridProps.height,
          //childAspectRatio: _uikProductCardGridProps.childAspectRatio,
          crossAxisSpacing: 16.0,
          // mainAxisSpacing: 16.0,
        ),
        itemBuilder: (BuildContext context, int index) {
          return Container(
            //  decoration: BoxDecoration(border: Border.all(color: Colors.pink)),
            child: _uikProductCardGridProps.productCards[index],
          );
        },
      ),
    );
  }
}
